IAM authentication backend for Django
=====================================

`django-auth-iam` is a Django authentication backend that uses the
Amazon IAM and SimpleDB services. The project is licensed under the
**GPL v3**.

